<p align="center">
  <img src="https://github.com/Getdeck/beiboot/raw/main/docs/static/img/logo.png" alt="Gefyra Logo"/>
</p>

# Getdeck Beiboot
_Getdeck Beiboot_ (or just Beiboot for brevity) is a Kubernetes-in-Kubernetes solution. It was born from the idea to 
provide Getdeck users a simple yet flexible solution to spin up **hybrid cloud development** infrastructure. This is 
useful for Kubernetes development workloads which grew too large to run on a development machine (or with pony workloads 
on MacOS and Windows machines). 

# Beiboot Client
The Beiboot client is a Python API to manage Beiboot clusters. It can set up and tear down Kubernetes instances
as well as establish connections.